@@ -14,3 +14,5 @@ class CarouselPortletAssignment(base.Assignment):
     limit = 5
     automatic_rotation = True
     omit_border = False
+    timeout = 8
+    carousel_extlink = ''
